@@ -16,8 +16,8 @@ def rocketmq_handler_wrapper(f):
 
 
 class ConsumerRocketMQ(ConsumerFactory):
-    def __init__(self, comsumer_group_name='', lookup_address='', node_address='', access_key='', access_secret='', thread_num=None, batch_size=None, **mq_options):
-        self.consumer = PushConsumer(comsumer_group_name)
+    def __init__(self, consumer_group_name='', lookup_address='', node_address='', access_key='', access_secret='', thread_num=None, batch_size=None, **mq_options):
+        self.consumer = PushConsumer(consumer_group_name)
         self.consumer.set_name_server_address(lookup_address)
         if thread_num and thread_num > 0:
             self.consumer.set_thread_count(thread_num)
